function bmsc64
% In this exercise we numerically compute the distribution of the maximum
% of a BM on [0,1]-BM_1, the absolute value of BM at time 1 and the maximum
% of a BM on [0,1]
tic
%% parameter input
% horizon
T=1;
% sample size
N=10^4;
% grid points
M=10^4;

% Simulate BM with normal increments
BM = [zeros(1,N);sqrt(T/M)*cumsum(randn(M,N))];
% initialize max(BM)-BM_1, max(BM) and |BM_1|
temp1 = repmat(max(BM),M+1,1)-BM;
X1 = temp1(end,:);
X2 = abs(BM(end,:));
temp3 = max(BM);
X3 = temp3(end,:);

% theoretical distribution function (cf. Ex 5-1)
theof = @(x) 2*normcdf(x)-1;
% empirical distribution function
[Fx1,x1]=ecdf(X1);
[Fx2,x2] = ecdf(X2);
[Fx3,x3]=ecdf(X3);
figure(1)
plot(x1,Fx1,'r-',x1,theof(x1),'b-');
title('distribution of max(BM)-BM');
xlabel('time');
ylabel('probabilities');
legend('ecdf of max(BM)-BM','theoretical');

figure(2)
plot(x2,Fx2,'r-',x2,theof(x2),'b-');
title('distribution of abs(BM)');
xlabel('time');
ylabel('probabilities');
legend('ecdf of abs(BM)','theoretical');

figure(3)
plot(x3,Fx3,'r-',x3,theof(x3),'b-');
title('distribution of max of BM');
xlabel('time');
ylabel('probabilities');
legend('ecdf of max BM','theoretical');
toc
end